@@ -304,13 +304,16 @@ public:
     ->Group(_(L"MENU_GAME",L"_Game"))
       ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_NEW",L"_New game"))
                                 .SetShortcut(Lum::OS::qualifierControl,L"g"),
-                                newGameAction))
+                                newGameAction)
+               .SetOpensDialog())
       ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_LAST_COMPUTER",L"_Show last _human move"))
                                 .SetShortcut(Lum::OS::qualifierControl,L"h"),
-                                lastHumanMoveAction))
+                                lastHumanMoveAction)
+               .SetOpensDialog())
       ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_LAST_HUMAN",L"Show last _computer move"))
                                 .SetShortcut(Lum::OS::qualifierControl,L"c"),
-                                lastComputerMoveAction))
+                                lastComputerMoveAction)
+               .SetOpensDialog())
     ->End()
     ->GroupHelp()
       //->ActionHelp()
